/*
 * © NHN Corp. All rights reserved.
 * NHN Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.toast.android.gamebase.sample.ui;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.ActivityNotFoundException;
import android.content.DialogInterface;
import android.content.Intent;
import android.net.Uri;
import android.os.Handler;
import android.os.Looper;
import android.widget.Switch;

import com.toast.android.gamebase.Gamebase;
import com.toast.android.gamebase.GamebaseCallback;
import com.toast.android.gamebase.GamebaseDataCallback;
import com.toast.android.gamebase.auth.data.AuthToken;
import com.toast.android.gamebase.auth.data.TemporaryWithdrawalInfo;
import com.toast.android.gamebase.base.GamebaseException;
import com.toast.android.gamebase.sample.GamebaseManager;

import java.util.Locale;

public class GameCodeManager {
    public static void showErrorAndReturnToTitle(final Activity activity, final String title, final String message) {
        final DialogInterface.OnClickListener returnToTitle = new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                returnToTitle(activity);
            }
        };
        Gamebase.Util.showAlert(activity, title, message, returnToTitle);
    }

    public static void showUnregisteredVersionAndMoveToStore(final Activity activity, final String updateUrl, final String message) {
        final int requestCode = 123;
        final DialogInterface.OnClickListener moveToStore = new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                try {
                    Intent marketIntent = new Intent(Intent.ACTION_VIEW);
                    marketIntent.setData(Uri.parse(updateUrl));

                    activity.startActivityForResult(marketIntent, requestCode);
                } catch (ActivityNotFoundException ignored) {
                }
            }
        };
        Gamebase.Util.showAlert(activity, "Unregistered Game Version", message, moveToStore);
    }

    public static void returnToTitle(final Activity activity) {
        activity.finish();
    }

    public static void showError(final Activity activity, final String title, final String message) {
        Gamebase.Util.showAlert(activity, title, message);
    }

    public static void moveToLoginScene(final Activity activity) {
        SplashActivity.LoadLoginActivity(activity);
    }

    public static void returnToLoginScene(final Activity activity) {
        try {
            ((MainActivity) activity).loadLoginFragment();
        } catch (Exception ignored) {
        }
    }

    public static void moveToInGameStore(final Activity activity) {
        try {
            ((MainActivity) activity).loadPurchaseFragment();
        } catch (Exception ignored) {
        }
    }

    public static void moveToPushSettingsMenu(final Activity activity) {
        try {
            ((MainActivity) activity).loadPushFragment();
        } catch (Exception ignored) {
        }
    }

    public static void startGame(final Activity activity) {
        ((MainActivity) activity).loadApiListFragment();
    }

    public static void addMappingAndChangeAccountUI(final Activity activity, final String providerName, final Switch mappingSwitch) {
        GamebaseManager.addMapping(activity, providerName, new GamebaseDataCallback<AuthToken>() {
            @Override
            public void onCallback(AuthToken authToken, GamebaseException exception) {
                if (Gamebase.isSuccess(exception)) {
                    changeAccountSwitchUI(activity, mappingSwitch, true);
                } else {
                    changeAccountSwitchUI(activity, mappingSwitch, false);
                }
            }
        });
    }

    public static void removeMappingAndChangeAccountUI(final Activity activity, final String providerName, final Switch mappingSwitch) {
        GamebaseManager.removeMapping(activity, providerName, new GamebaseCallback() {
            @Override
            public void onCallback(GamebaseException exception) {
                if (Gamebase.isSuccess(exception)) {
                    // succeeded
                } else {
                    changeAccountSwitchUI(activity, mappingSwitch, true);
                }
            }
        });
    }

    private static void changeAccountSwitchUI(final Activity activity, final Switch changeSwitch, final boolean flag) {
        activity.runOnUiThread(new Runnable() {
            @Override
            public void run() {
                changeSwitch.setChecked(flag);
            }
        });
    }

    public static void showTemporaryWithdrawUI(final Activity activity,
                                               final TemporaryWithdrawalInfo temporaryWithdrawalInfo,
                                               final GamebaseManager.Callback callback) {
        if (activity == null || temporaryWithdrawalInfo == null) {
            if (callback != null) callback.onCallback();
            return;
        }
        new Handler(Looper.getMainLooper()).post(new Runnable() {
            @Override
            public void run() {
                String date = new java.text.SimpleDateFormat("MM/dd/yyyy HH:mm:ss", Locale.getDefault())
                        .format(new java.util.Date(temporaryWithdrawalInfo.getGracePeriodDate()));
                new AlertDialog.Builder(activity)
                        .setTitle("This account will be erased!")
                        .setMessage("You can login until : " + date)
                        .setPositiveButton("OK", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                if (callback != null) callback.onCallback();
                            }
                        })
                        .setCancelable(false)
                        .show();
            }
        });
    }
}
