/*
 * © NHN Corp. All rights reserved.
 * NHN Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

package com.toast.android.gamebase.sample.ui;


import android.os.Bundle;
import androidx.fragment.app.Fragment;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.CompoundButton;
import android.widget.Switch;
import android.widget.Toast;

import com.toast.android.gamebase.Gamebase;
import com.toast.android.gamebase.GamebaseCallback;
import com.toast.android.gamebase.GamebaseDataCallback;
import com.toast.android.gamebase.base.GamebaseException;
import com.toast.android.gamebase.base.push.PushConfiguration;
import com.toast.android.gamebase.base.push.data.GamebasePushTokenInfo;
import com.toast.android.gamebase.sample.util.Log;
import com.toast.android.gamebase.sample.GamebaseManager;
import com.toast.android.gamebase.sample.R;
import com.toast.android.gamebase.sample.util.AppUtil;


public class PushFragment extends Fragment {

    private static final String TAG = PushFragment.class.getSimpleName();
    private static View mCurrentView = null;

    private static Switch mSwitchAdvertisement = null;
    private static Switch mSwitchAdvertisementNight = null;
    private static Switch mSwitchNotification = null;
    private static Switch mSwitchForeground = null;

    private static boolean mAgreeAdvertisement = false;
    private static boolean mAgreeAdvertisementNight = false;
    private static boolean mEnableNotification = false;
    private static boolean mEnableForeground = false;

    public PushFragment() {
        // Required empty public constructor
    }


    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container,
                             Bundle savedInstanceState) {

        setHasOptionsMenu(true);

        mCurrentView = inflater.inflate(R.layout.fragment_push, container, false);

        getPushStatus();
        setPushAgreement();

        return mCurrentView;
    }


    ////////////////////////////////////////////////////////////////////////////////////////////////
    // Action Bar Item Setting
    @Override
    public void onCreateOptionsMenu(Menu menu, MenuInflater inflater) {
        menu.clear();
        super.onCreateOptionsMenu(menu, inflater);

        inflater.inflate(R.menu.main, menu);

        MenuItem logoutItem = menu.findItem(R.id.action_logout);
        logoutItem.setVisible(false);
        MenuItem closeItem = menu.findItem(R.id.action_activityClose);
        closeItem.setVisible(true);
        MenuItem logOpenItem = menu.findItem(R.id.action_log);
        logOpenItem.setVisible(true);

    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        ((MainActivity) getActivity()).actionItemEvent(item);
        return super.onOptionsItemSelected(item);
    }
    ////////////////////////////////////////////////////////////////////////////////////////////////

    private void setPushAgreement() {
        mSwitchAdvertisement = mCurrentView.findViewById(R.id.switch_adv);
        mSwitchAdvertisementNight = mCurrentView.findViewById(R.id.switch_adv_Night);
        mSwitchNotification = mCurrentView.findViewById(R.id.switch_notification);
        mSwitchForeground = mCurrentView.findViewById(R.id.switch_foreground_notification);

        mSwitchAdvertisement.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mAgreeAdvertisement = mSwitchAdvertisement.isChecked();
                registerPush(mEnableNotification, mAgreeAdvertisement, mAgreeAdvertisementNight, mSwitchAdvertisement);
            }
        });

        mSwitchAdvertisementNight.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mAgreeAdvertisementNight = mSwitchAdvertisementNight.isChecked();
                registerPush(mEnableNotification, mAgreeAdvertisement, mAgreeAdvertisementNight, mSwitchAdvertisementNight);
            }
        });

        mSwitchNotification.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mEnableNotification = mSwitchNotification.isChecked();
                registerPush(mEnableNotification, mAgreeAdvertisement, mAgreeAdvertisementNight, mSwitchNotification);
            }
        });

        mSwitchForeground.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                mEnableForeground = mSwitchForeground.isChecked();
                GamebaseManager.enablePushForeground(getActivity(), mEnableForeground, null);
            }
        });

        mSwitchNotification.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                if (isChecked) {
                    mSwitchAdvertisement.setEnabled(true);
                    mSwitchForeground.setEnabled(true);
                } else {
                    mSwitchAdvertisement.setEnabled(false);
                    mSwitchAdvertisementNight.setEnabled(false);
                    mSwitchForeground.setEnabled(false);
                }
            }
        });

        mSwitchAdvertisement.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton buttonView, boolean isChecked) {
                if (isChecked) {
                    mSwitchAdvertisementNight.setEnabled(true);
                } else {
                    mSwitchAdvertisementNight.setEnabled(false);
                }
            }
        });
    }

    private void getPushStatus() {

        AppUtil.showProgressDialog(getActivity(), "Get Push Agreement Status ...");

        GamebaseManager.queryTokenInfo(getActivity(), new GamebaseDataCallback<GamebasePushTokenInfo>() {
            @Override
            public void onCallback(final GamebasePushTokenInfo data, GamebaseException exception) {
                if (Gamebase.isSuccess(exception)) {
                    getActivity().runOnUiThread(new Runnable() {
                        @Override
                        public void run() {
                            mAgreeAdvertisement = data.agreement.adAgreement;
                            mAgreeAdvertisementNight = data.agreement.adAgreementNight;
                            mEnableNotification = data.agreement.pushEnabled;
                            mEnableForeground = Gamebase.Push.getNotificationOptions(getContext()).isForegroundEnabled();

                            mSwitchAdvertisement.setChecked(mAgreeAdvertisement);
                            mSwitchAdvertisementNight.setChecked(mAgreeAdvertisementNight);
                            mSwitchNotification.setChecked(mEnableNotification);
                            mSwitchForeground.setChecked(mEnableForeground);

                            if (!mEnableNotification) {
                                mSwitchAdvertisement.setEnabled(false);
                                mSwitchAdvertisementNight.setEnabled(false);
                                mSwitchForeground.setEnabled(false);
                            } else if (!mAgreeAdvertisement) {
                                mSwitchAdvertisementNight.setEnabled(false);
                            }
                        }
                    });

                    AppUtil.dismissProgressDialog(getActivity());

                    Log.d(TAG, "Agree Advertisement : " + mAgreeAdvertisement);
                    Log.d(TAG, "Agree Advertisement Night : " + mAgreeAdvertisementNight);
                    Log.d(TAG, "Enable Notification : " + mEnableNotification);
                    Log.d(TAG, "Foreground Notification : " + mEnableForeground);
                    Log.d(TAG, "Push Token : " + data.token);

                    Gamebase.Util.showToast(getActivity(), "Notification Enable : " + mEnableNotification +
                                    "\nAdvertisement Agreement : " + mAgreeAdvertisement +
                                    "\nNight Advertisement Agreement : " + mAgreeAdvertisementNight,
                            Toast.LENGTH_SHORT);
                } else {

                    Gamebase.Util.showToast(getActivity(), "Failed Get AdvertisementAgreement ", Toast.LENGTH_SHORT);
                    Gamebase.Util.showAlert(getActivity(), "Error", exception.toJsonString());
                    AppUtil.dismissProgressDialog(getActivity());

                    Log.d(TAG, "Failed Get AdvertisementAgreement ");
                    Log.d(TAG, "exception Code : " + exception.getCode());
                    Log.d(TAG, "exception Message : " + exception.getMessage());
                    Log.d(TAG, "exception Domain : " + exception.getDomain());
                    Log.d(TAG, "exception Detail Code : " + exception.getDetailCode());
                    Log.d(TAG, "exception Detail Message: " + exception.getDetailMessage());
                    Log.d(TAG, "exception Detail Domain: " + exception.getDetailDomain());

                }
            }
        });
    }

    private void registerPush(final boolean enable, final boolean agree, final boolean agreeNight, final Switch currentSwitch) {

        AppUtil.showProgressDialog(getActivity(), "Register push ...");

        final PushConfiguration configuration = PushConfiguration.newBuilder(enable, agree, agreeNight).build();
        GamebaseManager.registerPush(getActivity(), configuration, new GamebaseCallback() {
            @Override
            public void onCallback(GamebaseException exception) {
                if (Gamebase.isSuccess(exception)) {
                    Gamebase.Util.showToast(getActivity(), "Success Register Push", Toast.LENGTH_SHORT);
                    AppUtil.dismissProgressDialog(getActivity());

                    getPushStatus();
                } else {
                    getActivity().runOnUiThread(new Runnable() {
                        @Override
                        public void run() {
                            currentSwitch.setChecked(false);
                        }
                    });
                    Gamebase.Util.showAlert(getActivity(), "Error", exception.toJsonString());
                    String errorMessage = "Failed Register Push - Notification Enable : " + enable + " | Advertisement Agreement : " + agree + " | Night Advertisement Agreement : " + agreeNight;
                    Gamebase.Util.showToast(getActivity(), errorMessage, Toast.LENGTH_SHORT);
                    AppUtil.dismissProgressDialog(getActivity());

                    Log.d(TAG, errorMessage);
                    Log.d(TAG, "exception Code : " + exception.getCode());
                    Log.d(TAG, "exception Message : " + exception.getMessage());
                    Log.d(TAG, "exception Domain : " + exception.getDomain());
                    Log.d(TAG, "exception Detail Code : " + exception.getDetailCode());
                    Log.d(TAG, "exception Detail Message: " + exception.getDetailMessage());
                    Log.d(TAG, "exception Detail Domain: " + exception.getDetailDomain());
                }
            }
        });
    }

}
